# Generated by roxygen2: do not edit by hand

S3method("[",obr_tbl)
S3method(as.data.frame,obr_tbl)
S3method(print,obr_tbl)
S3method(summary,obr_tbl)
export(clear_cache)
export(get_efo_economy)
export(get_efo_fiscal)
export(get_efo_table)
export(get_expenditure)
export(get_forecast_revisions)
export(get_forecasts)
export(get_incapacity_caseloads)
export(get_incapacity_spending)
export(get_monthly_profiles)
export(get_pension_projections)
export(get_policy_measures)
export(get_psnb)
export(get_psnd)
export(get_public_finances)
export(get_receipts)
export(get_welfare_spending)
export(list_efo_economy_measures)
export(list_forecast_series)
export(obr_actual_vs_forecast)
export(obr_as_of)
export(obr_compare_vintages)
export(obr_efo_catalogue)
export(obr_efo_vintages)
export(obr_fiscal_rules)
export(obr_forecast_panel)
export(obr_headroom)
export(obr_pin)
export(obr_pinned)
export(obr_provenance)
export(obr_unpin)
export(policy_measures_summary)
importFrom(stats,aggregate)
importFrom(utils,head)
importFrom(utils,packageVersion)
