#' @keywords internal
#' @concept OBR
#' @concept Office for Budget Responsibility
#' @concept fiscal policy
#' @concept public finances
#' @concept PSNB
#' @concept national debt
#' @concept UK budget
#' @concept economic forecasts
#' @importFrom utils head packageVersion
#' @importFrom stats aggregate
"_PACKAGE"
