% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tbl.R
\name{summary.obr_tbl}
\alias{summary.obr_tbl}
\title{Summary of an obr_tbl}
\usage{
\method{summary}{obr_tbl}(object, ...)
}
\arguments{
\item{object}{An \code{obr_tbl} object.}

\item{...}{Unused.}
}
\value{
Invisibly returns the provenance list.
}
\description{
Returns the full provenance card and a structural summary of the data.
}
